@@ -249,16 +249,15 @@ sub compose {
     ##
     my @list = ();
     for my $bi (@effective_index) {
-	my @matched = do {
-	    if ($self->{stretch}) {
-		$bp->[$bi];
-	    } else {
-		merge_regions({ nojoin => 1, destructive => 1 },
-			      @{$mp->[$bi][MUST_LIST]},
-			      @{$mp->[$bi][POSI_LIST]},
-			      @{$mp->[$bi][NEGA_LIST]});
-	    }
-	};
+	my @matched = merge_regions({ nojoin => 1, destructive => 1 },
+				    @{$mp->[$bi][MUST_LIST]},
+				    @{$mp->[$bi][POSI_LIST]},
+				    @{$mp->[$bi][NEGA_LIST]});
+	if ($self->{stretch}) {
+	    my $b = $bp->[$bi];
+	    my $m = $matched[0];
+	    @matched = [ $b->[0], $b->[1], $m->[2], $m->[3] ];
+	}
 	$self->{MATCHED} += @matched;
 	if ($self->{only}) {
 	    push @list, map({ [ $_, $_ ] } @matched);
