@@ -122,7 +122,7 @@ sub load_file {
     for my $file (@_) {
 	my $select = (!-f $file and $file =~ s/\[([\d:,]+)\]$//) ? $1 : undef;
 	open my $fh, '<:encoding(utf8)', $file or die "$file: $!\n";
-	my @p = <$fh>;
+	my @p = map s/\\(?=\n)//gr, split /(?<!\\)\n/, do { local $/; <$fh> };
 	if ($select //= $arg->{select}) {
 	    my $numbers = Getopt::EX::Numbers->new(min => 1, max => int @p);
 	    my @select = do {
@@ -135,7 +135,7 @@ sub load_file {
 	    @p = @p[@select];
 	}
 	@p = do {
-	    map  { chomp ; s{\s*//.*}{}r }
+	    map  { chomp ; s{\s*//.*$}{}r }
 	    grep { not m{^\s*(?:#|//|$)} }
 	    @p;
 	};
